@@ -94,7 +94,7 @@ def check_type(value, tipo='boolean'):
              '1', 's', 'S', 'Si', 'si', 1, True}
     falses = {'falso', 'false', 'False',
               'f', '0', 'n', 'N', 'No', 'no', '', 0, False, None}
-    if tipo == 'int':
+    if tipo == 'int' and tipo.isdigit():
         value = int(value)
     elif tipo == 'boolean':
         if value in trues:
