@@ -2,6 +2,8 @@ import sys
 from dataclasses import dataclass
 from dataclasses_json import dataclass_json
 from enum import IntEnum 
+from datetime import datetime
+from boltons.tbutils import ExceptionInfo
 
 class Logger(IntEnum):
     NOTSET = 0
@@ -25,7 +27,8 @@ class MSGException:
     
     @property
     def info(self):
-        return (self.exc_type, self.value, self.traceback)
+        einfo = ExceptionInfo.from_exc_info(exc_type, self.value, self.traceback)
+        return einfo.to_dict()
 
 
     def __str__(self):
@@ -35,14 +38,14 @@ class MSGException:
 @dataclass
 class MessageLog:
     func_name: str
-    #timestamp: datetime
+    timestamp: datetime
     level: Logger
     message: str
     error: MSGException
 
     @property
     def msg(self):
-        return f"{self.func_name} :: {self.message}"
+        return f"{self.timestamp} :: {self.func_name} :: {self.message}"
 
     @property
     def exception(self):
@@ -58,3 +61,13 @@ class MessageLog:
 
     def __str__(self):
         return f"{self.func_name} :: {self.message} :: Error :> {self.exception}"
+
+    @property
+    def rdb(self):
+        return {
+            "function": self.func_name,
+            "DT_GEN": self.timestamp, 
+            "level": self.level, 
+            "message": self.message, 
+            "error": self.exc
+        }
